@@ -13,6 +13,7 @@ from pianosdk.publisher.models.address_config import AddressConfig
 from pianosdk.publisher.models.address_usage_info import AddressUsageInfo
 from pianosdk.publisher.models.advanced_email_model import AdvancedEmailModel
 from pianosdk.publisher.models.advanced_options import AdvancedOptions
+from pianosdk.publisher.models.afc_configuration import AfcConfiguration
 from pianosdk.publisher.models.app import App
 from pianosdk.publisher.models.app_features import AppFeatures
 from pianosdk.publisher.models.app_resource_count import AppResourceCount
@@ -32,6 +33,7 @@ from pianosdk.publisher.models.bulk_user_import_processing_request_dto import Bu
 from pianosdk.publisher.models.c2_experience_config import C2ExperienceConfig
 from pianosdk.publisher.models.categories_counter_model import CategoriesCounterModel
 from pianosdk.publisher.models.change_subscription_term_step import ChangeSubscriptionTermStep
+from pianosdk.publisher.models.check_can_upgrade_result import CheckCanUpgradeResult
 from pianosdk.publisher.models.check_users_email_result import CheckUsersEmailResult
 from pianosdk.publisher.models.checkout_flow import CheckoutFlow
 from pianosdk.publisher.models.checkout_flow_light_model import CheckoutFlowLightModel
@@ -43,6 +45,7 @@ from pianosdk.publisher.models.composer import Composer
 from pianosdk.publisher.models.configuration_property_metadata import ConfigurationPropertyMetadata
 from pianosdk.publisher.models.consent import Consent
 from pianosdk.publisher.models.consent_box_entry import ConsentBoxEntry
+from pianosdk.publisher.models.continuous_renewal_details import ContinuousRenewalDetails
 from pianosdk.publisher.models.contract import Contract
 
 
@@ -66,6 +69,7 @@ from pianosdk.publisher.models.create_billing_configuration_request import Creat
 from pianosdk.publisher.models.create_linked_term_request import CreateLinkedTermRequest
 from pianosdk.publisher.models.credit_guard_stored_fields import CreditGuardStoredFields
 from pianosdk.publisher.models.currency import Currency
+from pianosdk.publisher.models.cyber_source_capture_context_dto import CyberSourceCaptureContextDto
 from pianosdk.publisher.models.datatrans_initiate_transaction_response import DatatransInitiateTransactionResponse
 from pianosdk.publisher.models.datatrans_properties import DatatransProperties
 from pianosdk.publisher.models.delivery_period_read_view import DeliveryPeriodReadView
@@ -85,6 +89,7 @@ from pianosdk.publisher.models.dynamic_subscription_access_period_info import Dy
 from pianosdk.publisher.models.dynamic_subscription_details import DynamicSubscriptionDetails
 from pianosdk.publisher.models.dynamic_subscription_renewal_confirmation_dto import DynamicSubscriptionRenewalConfirmationDto
 from pianosdk.publisher.models.dynamic_term_access_period import DynamicTermAccessPeriod
+from pianosdk.publisher.models.early_billing_details import EarlyBillingDetails
 from pianosdk.publisher.models.easypay_configuration import EasypayConfiguration
 from pianosdk.publisher.models.edgil_payway_hosted_page_setup import EdgilPaywayHostedPageSetup
 from pianosdk.publisher.models.eigen_create_credit_card_info_dto import EigenCreateCreditCardInfoDto
@@ -103,6 +108,7 @@ from pianosdk.publisher.models.error_code import ErrorCode
 from pianosdk.publisher.models.error_codes import ErrorCodes
 from pianosdk.publisher.models.experian_configuration import ExperianConfiguration
 from pianosdk.publisher.models.experience import Experience
+from pianosdk.publisher.models.experience_metadata import ExperienceMetadata
 from pianosdk.publisher.models.experience_stat import ExperienceStat
 from pianosdk.publisher.models.experience_version import ExperienceVersion
 from pianosdk.publisher.models.export import Export
@@ -113,6 +119,7 @@ from pianosdk.publisher.models.external_api_field import ExternalAPIField
 from pianosdk.publisher.models.external_api_property_schema import ExternalAPIPropertySchema
 from pianosdk.publisher.models.external_api_provider_property import ExternalAPIProviderProperty
 from pianosdk.publisher.models.external_css import ExternalCss
+from pianosdk.publisher.models.generate_capture_context_params import GenerateCaptureContextParams
 from pianosdk.publisher.models.global_template import GlobalTemplate
 from pianosdk.publisher.models.global_template_deployment import GlobalTemplateDeployment
 from pianosdk.publisher.models.global_template_deployment_item import GlobalTemplateDeploymentItem
@@ -210,6 +217,7 @@ from pianosdk.publisher.models.period_reference_dto import PeriodReferenceDTO
 from pianosdk.publisher.models.period_settings import PeriodSettings
 from pianosdk.publisher.models.permission_dto import PermissionDTO
 from pianosdk.publisher.models.pp_configuration import PpConfiguration
+from pianosdk.publisher.models.ppc_currency_validation_dto import PpcCurrencyValidationDto
 from pianosdk.publisher.models.ppc_web_model import PpcWebModel
 from pianosdk.publisher.models.price_dto import PriceDTO
 from pianosdk.publisher.models.promo_code import PromoCode
@@ -315,7 +323,9 @@ from pianosdk.publisher.models.upgrade_offer_model import UpgradeOfferModel
 from pianosdk.publisher.models.upgrade_offer_option_model import UpgradeOfferOptionModel
 from pianosdk.publisher.models.upgrade_offer_variant import UpgradeOfferVariant
 from pianosdk.publisher.models.upgrade_option import UpgradeOption
+from pianosdk.publisher.models.upgrade_option_variants import UpgradeOptionVariants
 from pianosdk.publisher.models.upgrade_options import UpgradeOptions
+from pianosdk.publisher.models.upgrade_options_variant import UpgradeOptionsVariant
 from pianosdk.publisher.models.upgrade_sources import UpgradeSources
 from pianosdk.publisher.models.upgrade_subscription_step import UpgradeSubscriptionStep
 from pianosdk.publisher.models.upgrade_targets import UpgradeTargets
