@@ -4,11 +4,14 @@ from typing import Optional
 
 
 class DeliveryPeriodReadView(BaseModel):
-    is_editable: Optional[str] = None
-    to: Optional[str] = None
-    _from: Optional[str] = None
-    address_pub_id: Optional[str] = None
     delivery_period_pub_id: Optional[str] = None
+    _from: Optional[str] = None
+    is_donation: Optional[bool] = None
+    is_address_editable: Optional[str] = None
+    is_from_editable: Optional[str] = None
+    to: Optional[str] = None
+    is_to_editable: Optional[str] = None
+    address_pub_id: Optional[str] = None
     is_deletable: Optional[str] = None
 
 
